@@ -757,6 +757,93 @@ class HealthCheckProps:
         )
 
 
+class Kuma(
+    constructs.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@opencdk8s/cdk8s-kuma-types.Kuma",
+):
+    def __init__(
+        self,
+        scope: constructs.Construct,
+        name: builtins.str,
+        *,
+        gateway_whitelist: typing.Optional[typing.Sequence[builtins.str]] = None,
+        mesh: typing.Optional[builtins.str] = None,
+        service_whitelist: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ) -> None:
+        '''
+        :param scope: -
+        :param name: -
+        :param gateway_whitelist: 
+        :param mesh: 
+        :param service_whitelist: 
+        '''
+        opts = KumaOptions(
+            gateway_whitelist=gateway_whitelist,
+            mesh=mesh,
+            service_whitelist=service_whitelist,
+        )
+
+        jsii.create(self.__class__, self, [scope, name, opts])
+
+
+@jsii.data_type(
+    jsii_type="@opencdk8s/cdk8s-kuma-types.KumaOptions",
+    jsii_struct_bases=[],
+    name_mapping={
+        "gateway_whitelist": "gatewayWhitelist",
+        "mesh": "mesh",
+        "service_whitelist": "serviceWhitelist",
+    },
+)
+class KumaOptions:
+    def __init__(
+        self,
+        *,
+        gateway_whitelist: typing.Optional[typing.Sequence[builtins.str]] = None,
+        mesh: typing.Optional[builtins.str] = None,
+        service_whitelist: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ) -> None:
+        '''
+        :param gateway_whitelist: 
+        :param mesh: 
+        :param service_whitelist: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if gateway_whitelist is not None:
+            self._values["gateway_whitelist"] = gateway_whitelist
+        if mesh is not None:
+            self._values["mesh"] = mesh
+        if service_whitelist is not None:
+            self._values["service_whitelist"] = service_whitelist
+
+    @builtins.property
+    def gateway_whitelist(self) -> typing.Optional[typing.List[builtins.str]]:
+        result = self._values.get("gateway_whitelist")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
+    @builtins.property
+    def mesh(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("mesh")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def service_whitelist(self) -> typing.Optional[typing.List[builtins.str]]:
+        result = self._values.get("service_whitelist")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "KumaOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class Mesh(
     cdk8s.ApiObject,
     metaclass=jsii.JSIIMeta,
@@ -2127,6 +2214,208 @@ class TrafficTraceProps:
         )
 
 
+class TypedKumaExternalService(
+    constructs.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@opencdk8s/cdk8s-kuma-types.TypedKumaExternalService",
+):
+    def __init__(
+        self,
+        scope: constructs.Construct,
+        name: builtins.str,
+        *,
+        mesh: builtins.str,
+        service_address: builtins.str,
+        service_name: builtins.str,
+        service_protocol: builtins.str,
+    ) -> None:
+        '''
+        :param scope: -
+        :param name: -
+        :param mesh: 
+        :param service_address: 
+        :param service_name: 
+        :param service_protocol: 
+        '''
+        opts = TypedKumaExternalServiceOptions(
+            mesh=mesh,
+            service_address=service_address,
+            service_name=service_name,
+            service_protocol=service_protocol,
+        )
+
+        jsii.create(self.__class__, self, [scope, name, opts])
+
+
+@jsii.data_type(
+    jsii_type="@opencdk8s/cdk8s-kuma-types.TypedKumaExternalServiceOptions",
+    jsii_struct_bases=[],
+    name_mapping={
+        "mesh": "mesh",
+        "service_address": "serviceAddress",
+        "service_name": "serviceName",
+        "service_protocol": "serviceProtocol",
+    },
+)
+class TypedKumaExternalServiceOptions:
+    def __init__(
+        self,
+        *,
+        mesh: builtins.str,
+        service_address: builtins.str,
+        service_name: builtins.str,
+        service_protocol: builtins.str,
+    ) -> None:
+        '''
+        :param mesh: 
+        :param service_address: 
+        :param service_name: 
+        :param service_protocol: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "mesh": mesh,
+            "service_address": service_address,
+            "service_name": service_name,
+            "service_protocol": service_protocol,
+        }
+
+    @builtins.property
+    def mesh(self) -> builtins.str:
+        result = self._values.get("mesh")
+        assert result is not None, "Required property 'mesh' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def service_address(self) -> builtins.str:
+        result = self._values.get("service_address")
+        assert result is not None, "Required property 'service_address' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def service_name(self) -> builtins.str:
+        result = self._values.get("service_name")
+        assert result is not None, "Required property 'service_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def service_protocol(self) -> builtins.str:
+        result = self._values.get("service_protocol")
+        assert result is not None, "Required property 'service_protocol' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "TypedKumaExternalServiceOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+@jsii.data_type(
+    jsii_type="@opencdk8s/cdk8s-kuma-types.TypedKumaTrafficPermission",
+    jsii_struct_bases=[],
+    name_mapping={
+        "destination": "destination",
+        "mesh": "mesh",
+        "sources": "sources",
+        "destination_label": "destinationLabel",
+    },
+)
+class TypedKumaTrafficPermission:
+    def __init__(
+        self,
+        *,
+        destination: builtins.str,
+        mesh: builtins.str,
+        sources: typing.Sequence[builtins.str],
+        destination_label: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param destination: 
+        :param mesh: 
+        :param sources: 
+        :param destination_label: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "destination": destination,
+            "mesh": mesh,
+            "sources": sources,
+        }
+        if destination_label is not None:
+            self._values["destination_label"] = destination_label
+
+    @builtins.property
+    def destination(self) -> builtins.str:
+        result = self._values.get("destination")
+        assert result is not None, "Required property 'destination' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def mesh(self) -> builtins.str:
+        result = self._values.get("mesh")
+        assert result is not None, "Required property 'mesh' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def sources(self) -> typing.List[builtins.str]:
+        result = self._values.get("sources")
+        assert result is not None, "Required property 'sources' is missing"
+        return typing.cast(typing.List[builtins.str], result)
+
+    @builtins.property
+    def destination_label(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("destination_label")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "TypedKumaTrafficPermission(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+class TypedTrafficPermission(
+    constructs.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@opencdk8s/cdk8s-kuma-types.TypedTrafficPermission",
+):
+    def __init__(
+        self,
+        scope: constructs.Construct,
+        name: builtins.str,
+        *,
+        destination: builtins.str,
+        mesh: builtins.str,
+        sources: typing.Sequence[builtins.str],
+        destination_label: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param scope: -
+        :param name: -
+        :param destination: 
+        :param mesh: 
+        :param sources: 
+        :param destination_label: 
+        '''
+        opts = TypedKumaTrafficPermission(
+            destination=destination,
+            mesh=mesh,
+            sources=sources,
+            destination_label=destination_label,
+        )
+
+        jsii.create(self.__class__, self, [scope, name, opts])
+
+
 class VirtualOutbound(
     cdk8s.ApiObject,
     metaclass=jsii.JSIIMeta,
@@ -2770,6 +3059,8 @@ __all__ = [
     "FaultInjectionProps",
     "HealthCheck",
     "HealthCheckProps",
+    "Kuma",
+    "KumaOptions",
     "Mesh",
     "MeshInsight",
     "MeshInsightProps",
@@ -2792,6 +3083,10 @@ __all__ = [
     "TrafficRouteProps",
     "TrafficTrace",
     "TrafficTraceProps",
+    "TypedKumaExternalService",
+    "TypedKumaExternalServiceOptions",
+    "TypedKumaTrafficPermission",
+    "TypedTrafficPermission",
     "VirtualOutbound",
     "VirtualOutboundProps",
     "Zone",
